.. hdrbg documentation master file, created by
   sphinx-quickstart on Sat Mar 22 16:34:12 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

hdrbg documentation
===================

Pure python implementation of NIST SP800-90A Hash DRBG.

Other online resources:

- `project page on GitHub`_
- `Download Page`_ with releases
- This page, when viewed online is at https://hdrbg.readthedocs.io/en/latest/

.. _`project page on GitHub`: https://github.com/sebastien-riou/hash-drbg
.. _`Download Page`: http://pypi.python.org/pypi/hdrbg


.. toctree::
  :maxdepth: 4

  installation
  examples_python3
  api



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`